<!-- SPDX-FileCopyrightText: 2026 PythonWoods <dev@pythonwoods.dev> -->
<!-- SPDX-License-Identifier: Apache-2.0 -->

# Guide

Questa sezione contiene guide passo-passo per usare il progetto i18n Standard.

## Da dove iniziare

1. **[Setup avanzato](advanced/setup.md)** — configura una gerarchia di progetto profonda
   con supporto bilingue completo.
2. **[Ottimizzazione delle prestazioni](advanced/tuning.md)** — ottimizza la risoluzione
   dei link per alberi di documentazione di grandi dimensioni.

## Asset

Tutti gli asset condivisi si trovano in [`../assets/`](../assets/brand-kit.zip). Poiché
i file tradotti sono nella stessa cartella degli originali, il percorso relativo è identico
in entrambe le lingue.

Torna alla [Home](../index.md).
